==> drx-sdk-java-1.5.4-sources.jar: net/dreceiptx/receipt/allowanceCharge/SettlementType.java <==
/*
 * Copyright 2016 Digital Receipt Exchange Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.dreceiptx.receipt.allowanceCharge;

import com.google.gson.annotations.SerializedName;

public enum SettlementType {
    @SerializedName("ADZ")
    DeliveryFee("ADZ", "Delivery fee"),
    @SerializedName("FC")
    FreightFee("FC", "Freight fee"),
    @SerializedName("TIP")
    TIP("TIP", "Tip or Gratuity fee"),
    @SerializedName("PC")
    PackagingFee("PC", "Packaging fee"),
    @SerializedName("DI")
    GeneralDiscount("DI", "General discount"),
    @SerializedName("MB")
    MultiBuyDiscount("MB", "Multi-buy discount"),
    @SerializedName("FI")
    ProcessingFee("FI", "Admin or processing fee"),
    @SerializedName("BOK")
    BookingFee("BOK", "Booking fee");

    private String _value;
    private String _displayName;

    SettlementType(String value, String name) {
        _value = value;
        _displayName = name;
    }

    public String getValue() {
        return _value;
    }

    public String getDisplayName() {
        return _displayName;
    }

    @Override
    public String toString() {
        return _displayName;
    }
}

==> drx-sdk-java-1.8.2-sources.jar: net/dreceiptx/receipt/allowanceCharge/SettlementType.java <==
/*
 * Copyright 2016 Digital Receipt Exchange Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.dreceiptx.receipt.allowanceCharge;

import com.google.gson.annotations.SerializedName;

public enum SettlementType {
    @SerializedName("ADZ")
    DeliveryFee("ADZ", "Delivery fee"),
    @SerializedName("FC")
    FreightFee("FC", "Freight fee"),
    @SerializedName("TIP")
    TIP("TIP", "Tip or Gratuity fee"),
    @SerializedName("PC")
    PackagingFee("PC", "Packaging fee"),
    @SerializedName("DI")
    GeneralDiscount("DI", "General discount"),
    @SerializedName("MB")
    MultiBuyDiscount("MB", "Multi-buy discount"),
    @SerializedName("FI")
    ProcessingFee("FI", "Processing fee"),
    @SerializedName("BOK")
    BookingFee("BOK", "Booking fee"),
    @SerializedName("SER")
    ServiceFee("SER", "Service Fee"),
    @SerializedName("AEM")
    AdminFee("AEM", "Administrative services fee"),
    @SerializedName("AJ")
    AmendmentFee("AJ", "Adjustment/Amendment fee"),
    @SerializedName("HD")
    HandlingFee("HD", "Handling fee"),
    @SerializedName("AAB")
    ReturnOrCancellationFee("AAB", "Returned goods or cancellation fee");

    private String _value;
    private String _displayName;

    SettlementType(String value, String name) {
        _value = value;
        _displayName = name;
    }

    public String getValue() {
        return _value;
    }

    public String getDisplayName() {
        return _displayName;
    }

    @Override
    public String toString() {
        return _displayName;
    }
}
